@@ -1,5 +1,6 @@
 import pandas as pd
 import numpy as np
+import pickle
 from apache_beam.utils.timestamp import MIN_TIMESTAMP
 from apache_beam.utils.windowed_value import WindowedValue
 from apache_beam.transforms.window import GlobalWindow
@@ -23,6 +24,15 @@ def upload_blob(bucket_name, source_file_name, destination_blob_name):
     print('File {} uploaded to {}.'.format(source_file_name, destination_blob_name))
 
 
+def download_blob(bucket_name, source_file, destination_file):
+    storage_client = storage.Client()
+    bucket = storage_client.get_bucket(bucket_name)
+    blob = bucket.blob(source_file)
+    blob.download_to_filename(destination_file)
+
+    print('File {} downloaded to {}.'.format(source_file, destination_file))
+
+
 class _BatchingFn(DoFn):
 
     def __init__(self, batch_size=500):
@@ -63,53 +73,76 @@ class BatchingFn(PTransform):
 
 class _CreateCategoricalEncodedVariables(DoFn):
 
-    def __init__(self,
-                 load_equipment_mlb,
-                 quantile_mlb,
-                 state_transforms,
-                 city_transforms,
-                 source_transforms,
-                 email_transforms):
-
-        super(_CreateCategoricalEncodedVariables, self).__init__()
-        self.load_equipment_mlb = load_equipment_mlb
-        self.quantile_mlb = quantile_mlb
-        self.state_transforms = state_transforms
-        self.city_transforms = city_transforms
-        self.source_transforms = source_transforms
-        self.email_transforms = email_transforms
-
     def process(self, df):
 
         # Multi Label Binarizer Variables
         # Split out Equipment Types
+
+        download_blob("load_transforms", "load_equipment_mlb.pkl", "load_equipment_mlb.pkl")
+        with open('load_equipment_mlb.pkl', 'rb') as f:
+            equipment_mlb = pickle.load(f)
+
+        download_blob("load_transforms", "load_quantile_mlb.pkl", "load_quantile_mlb.pkll")
+        with open('load_equipment_mlb.pkl', 'rb') as f:
+            quantile_mlb = pickle.load(f)
+
+        download_blob("load_transforms", "load_state_lbe.pkl", "load_state_lbe.pkl")
+        with open('load_state_lbe.pkl', 'rb') as f:
+            state_lbe = pickle.load(f)
+
+        download_blob("load_transforms", "load_state_ohe.pkl", "load_state_ohe.pkl")
+        with open('load_state_ohe.pkl', 'rb') as f:
+            state_ohe = pickle.load(f)
+
+        download_blob("load_transforms", "load_city_lbe.pkl", "load_state_lbe.pkl")
+        with open('load_city_lbe.pkl', 'rb') as f:
+            city_lbe = pickle.load(f)
+
+        download_blob("load_transforms", "load_city_ohe.pkl", "load_city_ohe.pkl")
+        with open('load_city_ohe.pkl', 'rb') as f:
+            city_ohe = pickle.load(f)
+
+        download_blob("load_transforms", "load_source_lbe.pkl", "load_source_lbe.pkl")
+        with open('load_source_lbe.pkl', 'rb') as f:
+            source_lbe = pickle.load(f)
+
+        download_blob("load_transforms", "load_source_ohe.pkl", "load_source_ohe.pkl")
+        with open('load_source_ohe.pkl', 'rb') as f:
+            source_ohe = pickle.load(f)
+
+        download_blob("load_transforms", "load_email_lbe.pkl", "load_email_lbe.pkl")
+        with open('load_email_lbe.pkl', 'rb') as f:
+            email_lbe = pickle.load(f)
+
+        download_blob("load_transforms", "load_email_ohe.pkl", "load_equipment_mlb.pkl")
+        with open('load_email_ohe.pkl', 'rb') as f:
+            email_ohe = pickle.load(f)
+
         df["equipment_type_list"] = df["equipment_type_list"].str.split(pat=", ")
         df.equipment_type_list.fillna(value=u'', inplace=True)
 
         # Equipment Types
-        df["equipment_type_encoded"] = list(self.load_equipment_mlb.transform(df["equipment_type_list"]))
+        df["equipment_type_encoded"] = list(equipment_mlb.transform(df["equipment_type_list"]))
         df.drop("equipment_type_list", axis=1, inplace=True)
 
         # Weight
-        df["weight_quantile_encoded"] = list(self.quantile_mlb.transform(df["weight_quantile"]))
+        df["weight_quantile_encoded"] = list(quantile_mlb.transform(df["weight_quantile"]))
         df.drop("weight_quantile", axis=1, inplace=True)
 
         # Price
-        df["price_quantile_encoded"] = list(self.quantile_mlb.transform(df["price_quantile"]))
+        df["price_quantile_encoded"] = list(quantile_mlb.transform(df["price_quantile"]))
         df.drop("price_quantile", axis=1, inplace=True)
 
         # Per Mile Rate
-        df["per_mile_rate_quantile_encoded"] = list(self.quantile_mlb.transform(df["per_mile_rate_quantile"]))
+        df["per_mile_rate_quantile_encoded"] = list(quantile_mlb.transform(df["per_mile_rate_quantile"]))
         df.drop("per_mile_rate_quantile", axis=1, inplace=True)
 
         # Distance
-        df["distance_quantile_encoded"] = list(self.quantile_mlb.transform(df["distance_quantile"]))
+        df["distance_quantile_encoded"] = list(quantile_mlb.transform(df["distance_quantile"]))
         df.drop("distance_quantile", axis=1, inplace=True)
 
         # One Hot Encode Variables
         # Pickup State
-        state_lbe = self.state_transforms[0]
-        state_ohe = self.state_transforms[1]
         df.pickup_state.fillna(value=u'', inplace=True)
         start_state_encoded = state_lbe.transform(df['pickup_state'])
         df["pickup_state_encoded"] = list(state_ohe.transform(start_state_encoded.reshape(-1, 1)))
@@ -122,8 +155,6 @@ class _CreateCategoricalEncodedVariables(DoFn):
         df.drop("dropoff_state", axis=1, inplace=True)
 
         # Pickup City
-        city_lbe = self.city_transforms[0]
-        city_ohe = self.city_transforms[1]
         df.pickup_city.fillna(value=u'', inplace=True)
         pickup_city_encoded = city_lbe.transform(df['pickup_city'])
         df["pickup_city_encoded"] = list(city_ohe.transform(pickup_city_encoded.reshape(-1, 1)))
@@ -136,16 +167,12 @@ class _CreateCategoricalEncodedVariables(DoFn):
         df.drop("dropoff_city", axis=1, inplace=True)
 
         # Source
-        source_lbe = self.source_transforms[0]
-        source_ohe = self.source_transforms[1]
         df.source.fillna(value=u'', inplace=True)
         source_encoded = source_lbe.transform(df['source'])
         df["source_encoded"] = list(source_ohe.transform(source_encoded.reshape(-1, 1)))
         df.drop("source", axis=1, inplace=True)
 
         # Email
-        email_lbe = self.email_transforms[0]
-        email_ohe = self.email_transforms[1]
         df.contact_email.fillna(value=u'', inplace=True)
         email_encoded = email_lbe.transform(df['contact_email'])
         df["email_encoded"] = list(email_ohe.transform(email_encoded.reshape(-1, 1)))
@@ -156,28 +183,8 @@ class _CreateCategoricalEncodedVariables(DoFn):
 
 class CreateCategoricalEncodedVariables(PTransform):
 
-    def __init__(self,
-                 load_equipment_mlb,
-                 quantile_mlb,
-                 state_transforms,
-                 city_transforms,
-                 source_transforms,
-                 email_transforms):
-        super(CreateCategoricalEncodedVariables, self).__init__()
-        self.load_equipment_mlb = load_equipment_mlb
-        self.quantile_mlb = quantile_mlb
-        self.state_transforms = state_transforms
-        self.city_transforms = city_transforms
-        self.source_transforms = source_transforms
-        self.email_transforms = email_transforms
-
     def expand(self, pcoll):
-        return pcoll | ParDo(_CreateCategoricalEncodedVariables(self.load_equipment_mlb,
-                                                                self.quantile_mlb,
-                                                                self.state_transforms,
-                                                                self.city_transforms,
-                                                                self.source_transforms,
-                                                                self.email_transforms))
+        return pcoll | ParDo(_CreateCategoricalEncodedVariables())
 
 
 class _CreateLoadQuantiles(DoFn):
